from flask import request
from marshmallow import Schema, fields, post_load, validate, validates, ValidationError
from app.gateways.models import Gateways

class GatewaySchema(Schema):
    gateway_mac_address = fields.String(required=True, validate=validate.Length(max=255))
    gateway_name = fields.String(required=True)
    x_coordinate = fields.Float(required=False)
    y_coordinate = fields.Float(required=False)
    zone_id = fields.Integer(required=False)
    room_id = fields.Integer(required=False)
    site_id =fields.Integer(required=False)
    room_name=fields.String()
    @validates("room_name")
    def required_room_name(self, value):
        if not value:
            raise ValidationError("The Room Name field is required")
    @validates("gateway_name")
    def required_gateway_name(self, value):
        if not value:
            raise ValidationError("The Gateway Name field is required")
    @validates("gateway_mac_address")
    def validates_gateway_mac_address(self, value):
        if not value:
            raise ValidationError("The Gateway Mac Address is required")
        if request.method == 'POST':
            existing_user = Gateways.query.filter_by(gateway_mac_address=value).first()
            if existing_user:
                raise ValidationError("Gateway Mac Address already exists")
    @post_load
    def make_user(self, data, **kwargs):
        return data
gateway_schema = GatewaySchema()